@@ -53,6 +53,10 @@ class UnknownTypeException(Exception):
 
 
 class FormGenerator(object):
+    """
+    Base form generator, you can make your own form generators by inheriting
+    this class.
+    """
     TYPE_MAP = {
         types.BigInteger: IntegerField,
         types.SmallInteger: IntegerField,
@@ -81,11 +85,23 @@ class FormGenerator(object):
         types.Numeric: Decimal,
     }
 
-    def __init__(self, model_class, meta):
-        self.model_class = model_class
-        self.meta = meta
+    def __init__(self, form_class):
+        """
+        Initializes the form generator
+
+        :param form_class: ModelForm class to be used as the base of generation
+                           process
+        """
+        self.form_class = form_class
+        self.model_class = self.form_class.Meta.model
+        self.meta = self.form_class.Meta
 
     def create_form(self, form):
+        """
+        Creates the form.
+
+        :param form: ModelForm instance
+        """
         fields = set(self.model_class._sa_class_manager.values())
         tmp = []
         for field in fields:
@@ -113,9 +129,15 @@ class FormGenerator(object):
 
         return self.create_fields(form, fields)
 
-    def create_fields(self, form, fields):
-        for field in fields:
-            column = field.property
+    def create_fields(self, form, attributes):
+        """
+        Creates fields for given form based on given model attributes.
+
+        :param form: form to attach the generated fields into
+        :param attributes: model attributes to generate the form fields from
+        """
+        for attribute in attributes:
+            column = attribute.property
 
             if not isinstance(column, ColumnProperty):
                 continue
@@ -130,6 +152,8 @@ class FormGenerator(object):
     def skip_column(self, column_property):
         """
         Whether or not to skip column in the generation process.
+
+        :param column_property: SQLAlchemy ColumnProperty object
         """
         column = column_property.columns[0]
         if (not self.meta.include_primary_keys and column.primary_key or
@@ -149,7 +173,11 @@ class FormGenerator(object):
         return False
 
     def has_index(self, column):
-        """Whether or not this column has an index."""
+        """
+        Whether or not given column has an index.
+
+        :param column: Column object to inspect the indexes from
+        """
         if column.primary_key or column.foreign_keys:
             return True
         table = column.table
@@ -266,7 +294,8 @@ class FormGenerator(object):
         if column.unique:
             return Unique(
                 self.model_class,
-                getattr(self.model_class, column.name)
+                getattr(self.model_class, column.name),
+                get_session=self.form_class.get_session
             )
 
     def range_validator(self, column):
@@ -328,12 +357,14 @@ class ModelFormMeta(FormMeta):
         for class_ in reversed(class_list(cls)):
             if hasattr(class_, 'Meta'):
                 property_dict.update(properties(class_.Meta))
+
         cls.Meta = type('Meta', (object, ), property_dict)
+
         return FormMeta.__init__(cls, *args, **kwargs)
 
     def __call__(cls, *args, **kwargs):
         if cls.Meta.model:
-            generator = cls.Meta.form_generator(cls.Meta.model, cls.Meta)
+            generator = cls.Meta.form_generator(cls)
             generator.create_form(cls)
 
         return FormMeta.__call__(cls, *args, **kwargs)
@@ -345,6 +376,14 @@ def model_form_factory(base=Form):
     class ModelForm(base):
         __metaclass__ = ModelFormMeta
 
+        """
+        A function that returns SQLAlchemy session. This should be
+        assigned if you wish to use Unique validator. If you are using
+        Flask-SQLAlchemy along with WTForms-Alchemy you don't need to
+        set this.
+        """
+        get_session = None
+
         class Meta:
             model = None
 
